# based on the spec file from https://build.opensuse.org/package/view_file/home:Simmphonie/libx265/

Name:           x265
%define soname  95
%define libname lib%{name}
%define libsoname %{libname}-%{soname}
Version:        2.1
Release:        2.1
License:        GPL-2.0+
Summary:        A free h265/HEVC encoder - encoder binary
Url:            https://bitbucket.org/multicoreware/x265/wiki/Home
Group:          Productivity/Multimedia/Video/Editors and Convertors
Source0:        https://bitbucket.org/multicoreware/x265/downloads/%{name}_%{version}.tar.gz
Patch0:         arm.patch
BuildRequires:  gcc gcc-c++
BuildRequires:  cmake >= 2.8.8
# for openSUSE 13.1 only libnuma-devel = 2.0.8 is available, but version 2.0.9 or higher is required
# build against version 2.0.8 failes with "error: 'numa_bitmask_weight' was not declared in this scope"
%if ! ( 0%{?suse_version} == 1310 )
%ifarch x86_64
BuildRequires:  libnuma-devel >= 2.0.9
%endif
%endif
BuildRequires:  pkg-config
BuildRequires:  yasm >= 1.2.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
x265 is a free library for encoding next-generation H265/HEVC video
streams.

%package -n %{libsoname}
Summary:        A free H265/HEVC encoder - encoder binary
Group:          Productivity/Multimedia/Video/Editors and Convertors

%description -n %{libsoname}
x265 is a free library for encoding next-generation H265/HEVC video
streams.

%package -n %{libname}-devel
Summary:        Libraries and include file for the %{libname} encoder
Group:          Development/Libraries/C and C++
Requires:       %{buildrequires}
Requires:       %{libsoname} = %{version}
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}

%description -n %{libname}-devel
x265 is a free library for encoding next-generation H265/HEVC video
streams. 

%prep
%setup -q -n x265_%{version}
%patch0 -p1

%define FAKE_BUILDDATE %(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
sed -i -e "s/0.0/%{soname}.0/g" source/cmake/version.cmake


%build
export CXXFLAGS="%{optflags}"
export CFLAGS="%{optflags}"

cd build/linux
cmake  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
       -DLIB_INSTALL_DIR=%{_lib} \
       -DENABLE_TESTS=ON \
       -G "Unix Makefiles" \
       ../../source

make %{?_smp_mflags} VERBOSE=1

%install
cd build/linux
%makeinstall

rm -f %{buildroot}%{_libdir}/%{libname}.a

echo "%{libname}-%{soname}" > %{_sourcedir}/baselibs.conf

%post -n %{libsoname} -p /sbin/ldconfig
%postun -n %{libsoname} -p /sbin/ldconfig

%files -n %{libsoname}
%defattr(0644,root,root)
%{_libdir}/%{libname}.so.%{soname}*

%files 
%defattr(0755,root,root)
%{_bindir}/%{name}

%files -n %{libname}-devel
%defattr(0644,root,root)
%{_includedir}/%{name}.h
%{_includedir}/%{name}_config.h
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/%{libname}.so

%changelog
* Thu Sep 29 2016 idonmez@suse.com
- Update to version 2.1
  Encoder enhancements
  * Support for qg-size of 8
  * Support for inserting non-IDR I-frames at scenecuts and when
    running with settings for fixed-GOP (min-keyint = max-keyint)
  * Experimental support for slice-parallelism.
  API changes
  * Encode user-define SEI messages passed in through x265_picture
    object.
  * Disable SEI and VUI messages from the bitstream
  * Specify qpmin and qpmax
  * Control number of bits to encode POC.
  Bug fixes
  * QP fluctuation fix for first B-frame in mini-GOP for 2-pass
    encoding with tune-grain.
  * Assembly fix for crashes in 32-bit from dct_sse4.
  * Threadpool creation fix in windows platform.
* Sun Aug 28 2016 joerg.lorenzen@ki.tng.de
- Update to version 2.0
  API and Key Behavior Changes
  * x265_rc_stats added to x265_picture, containing all RC decision
    points for that frame.
  * PTL: high tier is now allowed by default, chosen only if
    necessary.
  * multi-pass: First pass now uses slow-firstpass by default,
    enabling better RC decisions in future passes.
  * pools: fix behaviour on multi-socketed Windows systems, provide
    more flexibility in determining thread and pool counts.
  * ABR: improve bits allocation in the first few frames, abr reset,
    vbv and cutree improved.
  New Features
  * uhd-bd: Enforce Ultra-HD Blu-ray Disc parameters
    (overrides any other settings).
  * rskip: Enables skipping recursion to analyze lower CU sizes
    using heuristics at different rd-levels. Provides good visual
    quality gains at the highest quality presets.
  * rc-grain: Enables a new rate control mode specifically for
    grainy content. Strictly prevents QP oscillations within and
    between frames to avoid grain fluctuations.
  * tune grain: A fully refactored and improved option to encode
    film grain content including QP control as well as analysis
    options.
  * asm: ARM assembly is now enabled by default, native or cross
    compiled builds supported on armv6 and later systems.
  Misc
  * An SSIM calculation bug was corrected
- soname bump to 87.
- Fixed arm.patch.
- Added libnuma-devel as buildrequires for arch x86_64 (except
  for openSUSE 13.1 because libnuma-devel >= 2.0.9 is required).
* Wed Feb  3 2016 idonmez@suse.com
- Update to version 1.9
  API Changes:
  * x265_frame_stats returns many additional fields: maxCLL, maxFALL,
    residual energy, scenecut and latency logging
  * --qpfile now supports frametype 'K"
  * x265 now allows CRF ratecontrol in pass N (N greater than or equal to 2)
  * Chroma subsampling format YUV 4:0:0 is now fully supported and tested
  New Features:
  * Quant offsets: This feature allows block level quantization offsets
    to be specified for every frame. An API-only feature.
  * --intra-refresh: Keyframes can be replaced by a moving column
    of intra blocks in non-keyframes.
  * --limit-modes: Intelligently restricts mode analysis.
  * --max-luma and --min-luma for luma clipping, optional for HDR use-cases
  * Emergency denoising is now enabled by default in very low bitrate,
    VBV encodes
  Presets and Performance:
  * Recently added features lookahead-slices, limit-modes, limit-refs
    have been enabled by default for applicable presets.
  * The default psy-rd strength has been increased to 2.0
  * Multi-socket machines now use a single pool of threads that can
    work cross-socket.
* Fri Nov 27 2015 aloisio@gmx.com
- Update to version 1.8:
  API Changes:
  * Experimental support for Main12 is now enabled. Partial
    assembly support exists.
  * Main12 and Intra/Still picture profiles are now supported.
    Still picture profile is detected based on
    x265_param::totalFrames.
  * Three classes of encoding statistics are now available
    through the API.
    + x265_stats - contains encoding statistics, available
    through x265_encoder_get_stats()
    + x265_frame_stats and x265_cu_stats - contains frame
    encoding statistics, available through recon x265_picture
  * --csv
  * x265_encoder_log() is now deprecated
  * x265_param::csvfn is also deprecated
  * --log-level now controls only console logging, frame
    level console logging has been removed.
  * Support added for new color transfer characteristic ARIB
    STD-B67
  New Features:
  * limit-refs
    + This feature limits the references analysed for
    individual CUS.
    + Provides a nice tradeoff between efficiency and
    performance.
    + aq-mode 3
  * A new aq-mode that provides additional biasing for
    low-light conditions.
  * An improved scene cut detection logic that allows
    ratecontrol to manage visual quality at fade-ins and
    fade-outs better.
  Preset and Tune Options:
  * tune grain
    + Increases psyRdoq strength to 10.0, and rdoq-level to 2.
    + qg-size
  * Default value changed to 32.
- soname bump to 68
- Reworked arm.patch for 1.8
* Fri May 29 2015 aloisio@gmx.com
- soname bump to 59
- Update to version 1.7
  * large amount of assembly code optimizations
  * some preliminary support for high dynamic range content
  * improvements for multi-library support
  * some new quality features
    (full documentation at: http://x265.readthedocs.org/en/1.7)
  * This release simplifies the multi-library support introduced
    in version 1.6. Any libx265 can now forward API requests to
    other installed libx265 libraries (by name) so applications
    like ffmpeg and the x265 CLI can select between 8bit and 10bit
    encodes at runtime without the need of a shim library or
    library load path hacks. See --output-depth, and
    http://x265.readthedocs.org/en/1.7/api.html#multi-library-interface
  * For quality, x265 now allows you to configure the quantization
    group size smaller than the CTU size (for finer grained AQ
    adjustments). See --qg-size.
  * x265 now supports limited mid-encode reconfigure via a new public
    method: x265_encoder_reconfig()
  * For HDR, x265 now supports signaling the SMPTE 2084 color transfer
    function, the SMPTE 2086 mastering display color primaries, and the
    content light levels. See --master-display, --max-cll
  * x265 will no longer emit any non-conformant bitstreams unless
  - -allow-non-conformance is specified.
  * The x265 CLI now supports a simple encode preview feature. See
  - -recon-y4m-exec.
  * The AnnexB NAL headers can now be configured off, via x265_param.bAnnexB
    This is not configurable via the CLI because it is a function of the
    muxer being used, and the CLI only supports raw output files. See
  - -annexb
  Misc:
  * --lossless encodes are now signaled as level 8.5
  * --profile now has a -P short option
  * The regression scripts used by x265 are now public, and can be found at:
    https://bitbucket.org/sborho/test-harness
  * x265's cmake scripts now support PGO builds, the test-harness can be
    used to drive the profile-guided build process.
* Tue Apr 28 2015 aloisio@gmx.com
- soname bumped to 51
- Update to stable version 1.6
  Perfomance changes:
  * heavy improvements for AVX2 capable platforms
    (Haswell and later Intel CPUs) and work efficiency
    improvements for multiple-socket machines.
  API changes:
  * --threads N replaced by --pools N,N and --lookahead-slices N
  * --[no-]rdoq-level N - finer control over RDOQ effort
  * --min-cu-size N - trade-off compression for performance
  * --max-tu-size N - trade-off compression for performance
  * --[no-]temporal-layers - code unreferenced B frames in temporal
    layer 1
  * --[no-]cip aliases added for --[no-]constrained-intra
  * Added support for new color transfer functions "smpte-st-2084"
    and "smpte-st-428
  * --limit-refs N was added, but not yet implemented
  * Deprecated x265_setup_primitives() was removed from the public
    API and is no longer exported DLLs
  Threading changes:
  * The x265 thread pool has been made NUMA aware.
  * The --threads  parameter, which used to specify a global
    pool size, has been replaced with a --pools parameter which
    allows you to specify a pool size per NUMA node (aka CPU socket
    or package). The default is still to allocate one pool worker
    thread per logical core on the machine, but with --pools one
    can isolate those threads to a given socket.
  * Other than socket isolation, the biggest visible change in the
    NUMA aware thread pools is the increase in work efficiency.
    The total utilization will generally decrease but the performance
    will increase since worker threads spend less time context
    switching.  Also, the threading of the lookahead was made more
    work-efficient. Each lookahead job is a much larger piece of work.
    Before (1.5):
    disable thread pool: --threads 1
    default thread pool: --threads 0
    restrict to 4 threads: --threads 4
    After (1.6):
    disable thread pools: --pools 0
    default thread pools: --pools *
    restrict to 4 threads: --pools 4
    restrict to 4 threads on socket 1: --pools -,4
    restrict to all threads on socket 0: --pools +,-
  Multi-lib interface:
  * In order to support runtime selection of a libx265
    shared library, we have introduced an x265_api structure
    and an x265_api_get() function. Applications which use
    this interface to acquire the libx265 functional interface
    will be able to use shim libraries to bind a particular build
    of libx265 at run time. See the API documentation for full
    details.
* Sun Feb 22 2015 aloisio@gmx.com
- soname bump
- Update to stable version 1.5
  * improvements in Main10 compression efficiency and performance
    and psycho-visual optimizations now enabled by default
  Feature additions:
  * analysis re-use features have been completed
  * rate control zones have been introduced
  * --tune grain introduced
  * deblocking tC and Beta offsets are now configurable
  * denoise is seperately configurable for inter and intra CUs
  * frame based CSV logging has been improved
  * New support for VTune task profiles
  Presets and defaults:
  * ultrafast no longer disables the deblocking loop filter
  * psy-rd defaults to 0.3   (was 0, disabled)
  * psy-rdoq defaults to 1.0 (was 0, disabled)
  * aq-mode defaults to 1    (was 2, auto-variance)
  * 4:2:2 and 4:4:4 encodes no longer generate compliance warnings
  API changes:
  * param.rc.rateTolerance has been removed and replaced with a simpler
    param.rc.bStrictCbr flag.
  * --log-level debug is now --log-level 4 instead of --log-level 3.
    A new 'frame' log level was inserted at level 3 in order to support
    frame level CSV logging without also enabling frame level console
    logging. Using the string name 'debug' is unambiguous as its
    behavior has not changed.
- version 1.4
  * large refactoring in the analysis code
  Feature additions:
  * --pmode (parallel mode decision)
  * --pme (parallel motion estimation).
  Presets and defaults:
  * --amp is now respected in RD levels 2, 3, and 4 (previously only
    in 5 and 6).
  * --b-intra is now respected in all RD levels.
  * --fast-cbf, which has only ever effective at RD levels 5 and 6,
    is no longer enabled uselessly in the fastest presets.
  * --weightb is now enabled by default at presets slower, veryslow,
    and placebo.
  * --cu-lossless was changed to only attempt a lossless encode of
    the best lossy encode method. This made --cu-lossless a much less
    expensive encode option to have enabled, and hopefully made the
    feature more robust and maintainable.
  * The upper threshold for --psy-rdoq was raised to 50 (from 10)
    since the higher values were found to be beneficial for sources
    with high frequency noise (film grain).
  * The default thread pool size logic was updated to account for the
    addition of --pmode and --pme (if WPP is disabled but --pmode or
  - -pme are enabled, a thread pool is still allocated).
* Mon Dec  8 2014 crrodriguez@opensuse.org
- Ensure we use the proper CXXFLAGS, CFLAGS and therefore
  debuginfo packages are generated correctly.
* Sat Oct  4 2014 aloisio@gmx.com
- Bumped to version hg20140928
* Thu Jun  5 2014 guillaume@opensuse.org
- Fix ARM build with arm.patch from Arch Linux:
  https://github.com/archlinuxarm/PKGBUILDs/blob/master/extra/x265/arm.patch
* Thu May  8 2014 Manfred.Tremmel@iiv.de
- added baselibs.conf
* Mon Mar 24 2014 Manfred.Tremmel@iiv.de
- initial build of todays mercurial checkout
